@@ -73,7 +73,7 @@ globalInstallHelper <- function(packages, remotes=c()) {
     if (length(parts) != 1) {
       package <- parts[1]
       version <- parts[2]
-      devtools::install_version(package, version=version, reload=FALSE)
+      remotes::install_version(package, version=version, reload=FALSE)
     } else {
       unversioned <- c(unversioned, package)
     }
@@ -98,7 +98,7 @@ globalInstallHelper <- function(packages, remotes=c()) {
       }
     }
 
-    devtools::install_deps(dir, reload=FALSE)
+    remotes::install_deps(dir, reload=FALSE)
   }
 }
 
@@ -120,20 +120,45 @@ globalRemove <- function(packages) {
   }
 }
 
-globalUpdate <- function(packages, remotes) {
-  versions <- list()
-  for (package in packages) {
-    package <- getName(package)
-    versions[package] <- as.character(packageVersion(package))
-  }
+globalUpdate <- function(packages, remotes, verbose) {
+  if (length(packages) == 0) {
+    oldPackages <- as.data.frame(utils::old.packages())
+    packages <- rownames(oldPackages)
 
-  globalInstallHelper(packages, remotes)
+    updates <- FALSE
 
-  for (package in packages) {
-    package <- getName(package)
-    currentVersion <- versions[package]
-    newVersion <- as.character(packageVersion(package))
-    success(paste0("Updated ", package, " to ", newVersion, " (was ", currentVersion, ")"))
+    for (package in packages) {
+      currentVersion <- as.character(packageVersion(package))
+
+      # double check, since old.packages() is sometimes wrong
+      repoVersion <- gsub("-", ".", oldPackages$ReposVer[package])
+
+      if (!identical(currentVersion, repoVersion)) {
+        utils::install.packages(package, quiet=!verbose)
+        newVersion <- as.character(packageVersion(package))
+        success(paste0("Updated ", package, " to ", newVersion, " (was ", currentVersion, ")"))
+        updates <- TRUE
+      }
+    }
+
+    if (!updates) {
+      success("All packages are up-to-date!")
+    }
+  } else {
+    versions <- list()
+    for (package in packages) {
+      package <- getName(package)
+      versions[package] <- as.character(packageVersion(package))
+    }
+
+    globalInstallHelper(packages, remotes)
+
+    for (package in packages) {
+      package <- getName(package)
+      currentVersion <- versions[package]
+      newVersion <- as.character(packageVersion(package))
+      success(paste0("Updated ", package, " to ", newVersion, " (was ", currentVersion, ")"))
+    }
   }
 }
 
@@ -144,14 +169,31 @@ installHelper <- function(remove=c(), desc=NULL, show_status=FALSE) {
 
   # configure local repos
   remotes <- desc$get_remotes()
-  repos <- c()
+  local_repos <- c()
+  bioc <- FALSE
   for (remote in remotes) {
     if (startsWith(remote, "local::")) {
       repo <- dirname(substring(remote, 8))
-      repos <- c(repos, repo)
+      local_repos <- c(local_repos, repo)
+    } else if (startsWith(remote, "bioc::")) {
+      bioc <- TRUE
     }
   }
-  packrat::set_opts(local.repos=repos, persist=FALSE)
+  packrat::set_opts(local.repos=local_repos, persist=FALSE)
+
+  repos <- getOption("repos")
+  if (bioc && is.na(repos["BioCsoft"])) {
+    # not ideal, will hopefully be fixed with
+    # https://github.com/rstudio/packrat/issues/507
+    bioc_repos <- c(
+      BioCsoft="https://bioconductor.org/packages/3.7/bioc",
+      BioCann="https://bioconductor.org/packages/3.7/data/annotation",
+      BioCexp="https://bioconductor.org/packages/3.7/data/experiment",
+      BioCworkflows="https://bioconductor.org/packages/3.7/workflows"
+    )
+
+    packrat::set_lockfile_metadata(repos=c(repos, bioc_repos))
+  }
 
   # use a temporary directly
   # this way, we don't update DESCRIPTION
@@ -168,8 +210,9 @@ installHelper <- function(remove=c(), desc=NULL, show_status=FALSE) {
   missing <- status[is.na(status$library.version), ]
   restore <- missing[!is.na(missing$packrat.version), ]
   need <- missing[is.na(missing$packrat.version), ]
+  missing_packrat <- status[is.na(status$packrat.version), ]
 
-  statusUpdated <- FALSE
+  status_updated <- FALSE
 
   if (nrow(restore) > 0) {
     suppressWarnings(packrat::restore(project=dir, prompt=FALSE))
@@ -198,27 +241,28 @@ installHelper <- function(remove=c(), desc=NULL, show_status=FALSE) {
     if (nrow(mismatch) > 0) {
       for (i in 1:nrow(mismatch)) {
         row <- mismatch[i, ]
-        devtools::install_version(row$package, version=row$version, reload=FALSE)
+        remotes::install_version(row$package, version=row$version, reload=FALSE)
       }
     }
-    statusUpdated <- TRUE
+    status_updated <- TRUE
   }
 
   # in case we're missing any deps
   # unfortunately, install_deps doesn't check version requirements
   # https://github.com/r-lib/devtools/issues/1314
   if (nrow(need) > 0 || length(remove) > 0) {
-    devtools::install_deps(dir, upgrade=FALSE, reload=FALSE)
-    statusUpdated <- TRUE
+    remotes::install_deps(dir, upgrade=FALSE, reload=FALSE)
+    status_updated <- TRUE
   }
 
-  if (statusUpdated || any(!status$currently.used)) {
+  if (status_updated || any(!status$currently.used)) {
     suppressMessages(packrat::clean(project=dir))
-    statusUpdated <- TRUE
+    status_updated <- TRUE
   }
 
-  if (statusUpdated) {
-    suppressMessages(packrat::snapshot(project=dir, prompt=FALSE, ignore.stale=TRUE))
+  if (status_updated || length(missing_packrat) > 0) {
+    # Bioconductor packages fail to download source
+    suppressMessages(packrat::snapshot(project=dir, prompt=FALSE, ignore.stale=TRUE, snapshot.sources=FALSE))
 
     # loaded packages like curl can be missing on Windows
     # so see if we need to restore again
@@ -234,7 +278,7 @@ installHelper <- function(remove=c(), desc=NULL, show_status=FALSE) {
   file.copy(file.path(packrat::project_dir(), "packrat", "packrat.lock"), file.path(jetpack_dir, "packrat.lock"), overwrite=TRUE)
 
   if (show_status) {
-    if (statusUpdated) {
+    if (status_updated) {
       status <- getStatus()
     }
 
@@ -310,7 +354,8 @@ prepCommand <- function() {
 ensureRepos <- function() {
   repos <- getOption("repos")
   if (repos["CRAN"] == "@CRAN@") {
-    options(repos=list(CRAN="https://cloud.r-project.org/"))
+    repos["CRAN"] = "https://cloud.r-project.org/"
+    options(repos=repos)
   }
 }
 
@@ -321,7 +366,8 @@ prepGlobal <- function() {
 }
 
 sandbox <- function(code) {
-  libs <- c("jsonlite", "withr", "devtools", "httr", "curl", "git2r", "desc", "docopt")
+  libs <- c("remotes", "desc", "docopt")
+
   if (!interactive()) {
     suppressMessages(packrat::extlib(libs))
     invisible(eval(code))
@@ -666,84 +712,6 @@ check <- function() {
   })
 }
 
-#' Get info for a package
-#'
-#' @param package Package to get info for
-#' @importFrom utils URLencode
-#' @export
-#' @examples \dontrun{
-#'
-#' jetpack::info("stringr")
-#'
-#' jetpack::info("stringr@1.0.0")
-#' }
-info <- function(package) {
-  sandbox({
-    parts <- strsplit(package, "@")[[1]]
-    version <- NULL
-    if (length(parts) != 1) {
-      package <- parts[1]
-      version <- parts[2]
-    }
-    url <- paste0("https://crandb.r-pkg.org/", URLencode(package))
-    if (!is.null(version)) {
-      url <- paste0(url, "/", URLencode(version))
-    }
-    r <- httr::GET(url)
-    error <- httr::http_error(r)
-    if (error) {
-      stop("Package not found")
-    }
-    body <- httr::content(r, "parsed")
-    message(paste(body$Package, body$Version))
-    message(paste("Title:", body$Title))
-    message(paste("Date:", body$Date))
-    message(paste("Author:", oneLine(body$Author)))
-    message(paste("Maintainer:", oneLine(body$Maintainer)))
-    message(paste("License:", body$License))
-  })
-}
-
-#' Search for packages
-#'
-#' @param query Search query
-#' @export
-#' @examples \dontrun{
-#'
-#' jetpack::search("xgboost")
-#' }
-search <- function(query=NULL) {
-  # hack for R CMD check bug in share/R/examples-header.R
-  if (is.null(query) && exists("cleanEx")) {
-    return(base::search())
-  }
-
-  sandbox({
-    post_body <- list(
-      query=list(
-        function_score=list(
-          query=list(multi_match = list(query=query, fields=c("Package^10", "_all"), operator="and")),
-          functions=list(list(script_score=list(script="cran_search_score")))
-        )
-      ),
-      size=1000
-    )
-    r <- httr::POST("http://seer.r-pkg.org:9200/_search", body=post_body, encode="json")
-    error <- httr::http_error(r)
-    if (error) {
-      stop("Network error")
-    }
-    body <- httr::content(r, "parsed")
-    hits <- body$hits$hits
-    if (length(hits) > 0) {
-      for (i in 1:length(hits)) {
-        hit <- hits[i][[1]]
-        message(paste0(hit$`_id`, " ", hit$`_source`$Version, ": ", oneLine(hit$`_source`$Title)))
-      }
-    }
-  })
-}
-
 #' Install the command line interface
 #'
 #' @param file The file to create
@@ -788,13 +756,11 @@ run <- function() {
     jetpack remove <package>... [--remote=<remote>]...
     jetpack update <package>... [--remote=<remote>]...
     jetpack check
-    jetpack info <package>
-    jetpack search <query>
     jetpack version
     jetpack help
     jetpack global add <package>... [--remote=<remote>]...
     jetpack global remove <package>... [--remote=<remote>]...
-    jetpack global update <package>... [--remote=<remote>]...
+    jetpack global update [<package>...] [--remote=<remote>]... [--verbose]
     jetpack global list"
 
     opts <- NULL
@@ -820,7 +786,7 @@ run <- function() {
           # and easy to reverse global add
           globalRemove(opts$package)
         } else if (opts$update) {
-          globalUpdate(opts$package, opts$remote)
+          globalUpdate(opts$package, opts$remote, opts$verbose)
         } else {
           globalList()
         }
@@ -840,10 +806,6 @@ run <- function() {
         version()
       } else if (opts$help) {
         message(doc)
-      } else if (opts$info) {
-        info(opts$package)
-      } else if (opts$search) {
-        search(opts$query)
       } else {
         install(deployment=opts$deployment)
       }
